@@ -42,10 +42,11 @@ moment_estimation <- function (x, dist="NORM") {
   c(mux-sdx*muy/sdy, sdx/sdy)
  }
  else if (dist=="GEV") {
-  data(functionsLaio)
-  #.kgev <- read.table("kgev.dat") # .kgev is a matrix with the skewness coefficient (first column) 
+  data(functionsLaio, envir=environment())
+  #df.kgev <- read.table("kgev.dat") # df.kgev is a matrix with the skewness coefficient (first column) 
                                  # and the corresponding shape parameter of the GEV (second column)
-  T3 <- approx(.kgev[,1], .kgev[,2], skx)$y
+  df.kgev  <- get("df.kgev", envir=environment())
+  T3 <- approx(df.kgev[,1], df.kgev[,2], skx)$y
   T2 <- abs(T3)*sdx/(gamma(1+2*T3)-(gamma(1+T3))^2)^0.5
   T1 <- mux-T2/T3*(1-gamma(1+T3))
   c(T1,T2,T3)
@@ -131,23 +132,25 @@ ML_estimation <- function (x, dist="NORM") {
   T3 <- 1/n/T2*sum(x-T1)   # shape parameter, Johnson et al. [1994], eq. 17.45
   T4 <- 0
   if ((T3<2)&&(T2>0)) {   # non-regular estimation, see Smith [1985]
-   data(functionsLaio)
-   #.polig <- read.table("polig.dat")  # Funzione poligamma
+   data(functionsLaio, envir=environment())
+   #df.polig <- read.table("polig.dat")  # Funzione poligamma
+   df.polig <- get("df.polig", envir=environment())
    T4 <- 1
    b <- sort(x)
    T1 <- b[1]    # position parameter= first order statistic
    z <- b[2:n]-T1
-   T3 <- approx(.polig[,2], .polig[,1], sum(log(z))/(n-1)-log(mean(z)))$y  # shape parameter, Johnson et al. [1994], eq. 17.48
+   T3 <- approx(df.polig[,2], df.polig[,1], sum(log(z))/(n-1)-log(mean(z)))$y  # shape parameter, Johnson et al. [1994], eq. 17.48
    T2 <- mean(z)/T3
   }
   else if ((T3<2)&&(T2<0)) {
-   data(functionsLaio)
-   #.polig <- read.table("polig.dat")
+   data(functionsLaio, envir=environment())
+   #df.polig <- read.table("polig.dat")
+   df.polig <- get("df.polig", envir=environment())
    T4 <- 1
    b <- sort(x)
    T1 <- b[n]    # position parameter= n-th order statistic
    z <- b[1:(n-1)]-T1
-   T3 <- approx(.polig[,2], .polig[,1], sum(log(abs(z)))/(n-1)-log(mean(abs(z))))$y  # shape parameter, Johnson et al. [1994], eq. 17.45
+   T3 <- approx(df.polig[,2], df.polig[,1], sum(log(abs(z)))/(n-1)-log(mean(abs(z))))$y  # shape parameter, Johnson et al. [1994], eq. 17.45
    T2 <- mean(z)/T3
   }
   c(T1,T2,T3)
